summaryrefslogtreecommitdiffstats
path: root/ksim/library/label.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksim/library/label.h')
-rw-r--r--ksim/library/label.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/ksim/library/label.h b/ksim/library/label.h
index a888d89..f20d8df 100644
--- a/ksim/library/label.h
+++ b/ksim/library/label.h
@@ -42,7 +42,7 @@ namespace KSim
/**
* Constructs a KSim::Label.
*
* @param tqparent is the tqparent widget
*
* Example usage:
* <pre>
@@ -51,12 +51,12 @@ namespace KSim
* To create a KSim::Label with the normal theme look
* @see KSim::ThemeLoader
*/
- Label(TQWidget *tqparent, const char *name = 0, WFlags fl = 0);
+ Label(TQWidget *parent, const char *name = 0, WFlags fl = 0);
/**
* Constructs a KSimLabel.
*
* @param type is the theme type
* @param tqparent is the tqparent widget
*
* Example usage:
* <pre>
@@ -66,13 +66,13 @@ namespace KSim
* NOTE: this is the same as the KSim::Label(TQWidget *, const char *, WFlags) ctor
* @see KSim::ThemeLoader
*/
- Label(int type, TQWidget *tqparent, const char *name = 0, WFlags fl = 0);
+ Label(int type, TQWidget *parent, const char *name = 0, WFlags fl = 0);
/**
* Constructs a KSim::Label.
*
* @param type is the theme type
* @param text is the default text to display
* @param tqparent is the tqparent widget
*
* Example usage:
* <pre>
@@ -82,7 +82,7 @@ namespace KSim
* @see KSim::ThemeLoader
*/
Label(int type, const TQString &text,
- TQWidget *tqparent, const char *name = 0, WFlags fl = 0);
+ TQWidget *parent, const char *name = 0, WFlags fl = 0);
/**
* destructs KSim::Label.
*/
@@ -42,7 +42,7 @@ namespace KSim
* Constructs a KSim::Label.
*
- * @param tqparent is the tqparent widget
+ * @param parent is the parent widget
*
* Example usage:
@@ -51,12 +51,12 @@ namespace KSim
*
* @param type is the theme type
- * @param tqparent is the tqparent widget
+ * @param parent is the parent widget
*
* Example usage:
@@ -66,13 +66,13 @@ namespace KSim
* @param type is the theme type
* @param text is the default text to display
- * @param tqparent is the tqparent widget
+ * @param parent is the parent widget
*
* Example usage: